@@ -1,6 +1,11 @@
 class Error(Exception):
     """Error"""
 
+    def __init__(self, *args):
+        super(Error, self).__init__(*args)
+
+        self.stack = []
+
 
 class AttributeError(Error):
     """AttributeError"""
