@@ -1,13 +1,16 @@
 # -*- coding: utf-8 -*-
 
-import re
-from funcparserlib.lexer import make_tokenizer, Token
+from __future__ import print_function
 
+
+from funcparserlib.lexer import Token
 from funcparserlib.parser import forward_decl as fwd
 from funcparserlib.parser import a, many, maybe, skip, some
 
-import runtime
-from core.message import Message
+
+from mio import runtime
+from mio.lexer import operators
+from mio.core.message import Message
 
 tokval = lambda tok: tok.value
 sometok = lambda type: (some(lambda t: t.type == type) >> tokval)
@@ -15,63 +18,6 @@ op = lambda name: a(Token('op', name))
 op_ = lambda name: skip(op(name))
 Spec = lambda name, value: (name, (value,))
 
-operators = [
-    "**", "++", "--", "+=", "-=", "*=", "/=", "<<", ">>",
-    "==", "!=", "<=", ">=", "..",
-    "+", "-", "*", "/", "=", "<", ">", "!", "%", "|", "^", "&", "?", ":",
-    "is", "or", "and", "not", "return", "from", "import",
-]
-
-strtpl = """
-    {start:s}
-    [^\\{quote:s}]*?
-    (
-    (   \\\\[\000-\377]
-        |   {quote:s}
-        (   \\\\[\000-\377]
-        |   [^\\{quote:s}]
-        |   {quote:s}
-        (   \\\\[\000-\377]
-            |   [^\\{quote:s}]
-        )
-        )
-    )
-    [^\\{quote:s}]*?
-    )*?
-    {end:s}
-"""
-
-quotes = [
-    {"quote": "'", "start": "'''", "end": "'''"},
-    {"quote": '"', "start": '"""', "end": '"""'},
-    {"quote": "'", "start": "'", "end": "'"},
-    {"quote": '"', "start": '"', "end": '"'}
-]
-
-strre = "".join(strtpl.split())
-strre = "|".join([strre.format(**quote) for quote in quotes])
-strre = re.compile(strre.format(**quotes[3]))
-
-encodnig = "utf-8"
-
-
-def tokenize(str):
-
-    ops = "|".join([re.escape(op) for op in operators])
-
-    specs = [
-        Spec("comment",    r'#.*'),
-        Spec("whitespace", r"[ \t]+"),
-        Spec('string',     strre),
-        Spec('number',     r'(-?(0|([1-9][0-9]*))(\.[0-9]+)?([Ee]-?[0-9]+)?)'),
-        Spec('identifier', r'[A-Za-z_][A-Za-z0-9_]*'),
-        Spec('operator',   ops),
-        Spec('op',         r'[(){}\[\],:;\n\r]'),
-    ]
-    useless = ["comment", "whitespace"]
-    t = make_tokenizer(specs)
-    return [x for x in t(str) if x.type not in useless]
-
 
 def make_arguments(n):
     opening, expression, expressions, closing = n
@@ -129,6 +75,20 @@ def is_operator(message):
     return message.name in operators
 
 
+def reshuffle(ms):
+    r = []
+
+    while ms:
+        #x is not None --> not x is None
+        if len(ms) > 1 and ms[0].name == "is" and ms[1].name == "not":
+            r = r[:-1] + [ms[1], r[-1], ms[0]]
+            ms = ms[2:]
+            continue
+        r.append(ms.pop(0))
+
+    return r
+
+
 def make_chain(messages, all=True):
     root = node = None
 
@@ -147,20 +107,28 @@ def make_chain(messages, all=True):
             else:
                 value = make_chain(messages, all=False)
 
+            try:
+                assert key is not None
+                assert value is not None
+            except:
+                import pudb; pudb.set_trace()
             message = Message("set", args=[key, value])
         elif is_operator(messages[0]):
             message = messages.pop(0)
             if messages and not message.args:
-                arg = messages.pop(0)
-                arg.previous = message
-                message.args.append(arg)
-                message.call = True
-                #chain = make_chain(messages, all=False)
-                #if chain is not None:
-                #    # Set the argument (a Message) previous attribute to the current message
-                #    chain.previous = message
-                #    message.args.append(chain)
-                #    message.call = True
+                if operators.get(message.name)[0] == 1:
+                    arg = messages.pop(0)
+                    # Set the argument (a Message) previous attribute to the current message
+                    arg.previous = message
+                    message.args.append(arg)
+                    message.call = True
+                else:
+                    chain = make_chain(messages, all=False)
+                    if chain is not None:
+                        # Set the argument (a Message) previous attribute to the current message
+                        chain.previous = message
+                        message.args.append(chain)
+                        message.call = True
         elif messages[0].terminator and not all:
             break
         else:
@@ -174,6 +142,10 @@ def make_chain(messages, all=True):
     return root
 
 
+def make_expression(messages):
+    return make_chain(reshuffle(messages))
+
+
 def make_number(n):
     return runtime.find("Number").clone(n)
 
@@ -206,7 +178,7 @@ symbol = fwd()
 terminator = (op(";") | op("\r") | op("\n")) >> make_terminator
 
 expression.define((
-    many(message | terminator)) >> make_chain)
+    many(message | terminator)) >> make_expression)
 
 message.define(((symbol + maybe(arguments)) | arguments) >> make_message)
 
