@@ -5,9 +5,10 @@ from traceback import format_exc
 
 
 from .errors import Error
-from .version import version
+from .parser import parse
+from .lexer import tokenize
 from .utils import tryimport
-from .parser import parse, tokenize
+from .version import version
 
 from .core import Core
 from .types import Types
@@ -117,9 +118,17 @@ class State(object):
         try:
             return parse(tokenize(code)).eval(self.root if receiver is None else receiver, self.root if context is None else context, message)
         except Error as e:
-            type = e.__class__.__name__
+            if e.args and isinstance(e.args[0], Object):
+                error = e.args[0]
+                type = str(error["type"]) if error["type"] is not None else error.type
+                message = str(error["message"]) if error["message"] is not None else ""
+            else:
+                type = e.__class__.__name__
+                message = str(e)
+
+            stack = "\n".join([repr(m) for m in e.stack])
             underline = "-" * (len(type) + 1)
-            print("\n  %s: %s\n  %s\n  %r\n" % (type, e, underline, message))
+            print("\n  {0:s}: {1:s}\n  {2:s}\n  {3:s}\n".format(type, message, underline, stack))
             if reraise:
                 raise
         except Exception as e:  # pragma: no cover
@@ -142,9 +151,13 @@ class State(object):
                     result = self.eval(code)
                     if result is not None:  # pragma: no cover
                         if isinstance(result, Object):
-                            output = self.eval("repr()", receiver=result)
+                            if result.value is not None:
+                                output = self.eval("repr()", receiver=result)
+                            else:
+                                output = None
                         else:
                             output = repr(result)
-                        print("===> {0:s}".format(output))
+                        if output is not None:
+                            print("===> {0:s}".format(output))
             except EOFError:  # pragma: no cover
                 raise SystemExit(0)
