@@ -3,7 +3,7 @@ def test_simple(mio):
 
 
 def test_complex(mio):
-    assert mio.eval("1 + 2 * 3") == 9
+    assert mio.eval("1 + 2 * 3") == 7
 
 
 def test_grouping(mio):
@@ -24,7 +24,7 @@ def test_complex_assignment_expression(mio):
 
 
 def test_complex_assignment_attribute(mio):
-    mio.eval("Foo = Object clone")
+    mio.eval("Foo = Object clone()")
 
     mio.eval("Foo x = 1")
     assert mio.eval("Foo x") == 1
